@@ -267,7 +267,7 @@ class Highlighter(QSyntaxHighlighter):
         # Multi-line strings (expression, flag, style)
         # FIXME: The triple-quotes in these two lines will mess up the
         # syntax highlighting from this point onward
-#        self.tri_double = (QtCore.QRegExp(r'''"""(?!')'''), 2, STYLES['string2'])
+#        self.tri_double = ( QRegExp(r'''"""(?!')'''), 2, STYLES['string2'])
 
 #        rules += [(r'\b%s\b' % w, 0, STYLES['keyword']) for w in Highlighter.keywords]
 #        rules += [(r'\b%s\b' % w, 0, STYLES['preprocessor']) for w in Highlighter.preprocessors]
@@ -297,7 +297,7 @@ class Highlighter(QSyntaxHighlighter):
         self.multilines_comment = syntax._comments
 
         # Build a QRegExp for each pattern
-#        self.rules = [(QtCore.QRegExp(pat), index, fmt) for (pat, index, fmt) in rules]
+#        self.rules = [( QRegExp(pat), index, fmt) for (pat, index, fmt) in rules]
                         
     def highlightBlock(self, text):
         """Apply syntax highlighting to the given block of text.
@@ -309,7 +309,7 @@ class Highlighter(QSyntaxHighlighter):
             while index >= 0:
                 # We actually want the index of the nth match
                 index = expression.pos(nth)
-                length = expression.cap(nth).length()
+                length = len(expression.cap(nth))
                 self.setFormat(index, length, format)                
                 index = expression.indexIn(text, index + length)
 
@@ -354,7 +354,7 @@ class Highlighter(QSyntaxHighlighter):
             # No; multi-line string
             else:
                 self.setCurrentBlockState(in_state)
-                length = text.length() - start + add
+                length = len(text) - start + add
                 #print 'Text: ',text,',No Multiline start : ', start, ', add : ',add, ', end :', end, ', lenght :',length
             # Apply formatting
             self.setFormat(start, length, style)
@@ -370,4 +370,4 @@ class Highlighter(QSyntaxHighlighter):
 if __name__ == '__main__':
     syntax = XMLSyntaxParser('cpp')
     print syntax._grammar
-    print syntax._comments
+    print syntax._comments
\ No newline at end of file
